@@ -1,12 +1,11 @@
 import importlib.metadata
 
-from .matcher import FileExists as FileExistsMatcher
-from .matcher import LineInFile as LineInFileMatcher
-from .matcher import RepoName as RepoNameMatcher
 from .rcmt import execute, execute_local, options_from_config
 from .run import Run
 
+__all__ = ["Run", "execute", "execute_local", "options_from_config"]
+
 try:
     __version__ = importlib.metadata.version(__name__)
-except:
+except Exception:
     __version__ = "develop"
