@@ -1,6 +1,6 @@
 import datetime
 import urllib.parse
-from typing import Any, Optional, TextIO, Union
+from typing import Any, Generator, Optional, TextIO, Union
 
 import humanize
 
@@ -75,19 +75,20 @@ class PullRequest:
         body += "\n---\n\n"
 
         body += "**Automerge:** "
+        # Add two spaces at the end of each line to make GitLab create a line break.
         if self.auto_merge is True:
             if self.auto_merge_after is None:
-                body += "Enabled. rcmt merges this automatically on its next run and if all checks have passed.\n"
+                body += "Enabled. rcmt merges this automatically on its next run and if all checks have passed.  \n"
             else:
                 after = humanize.naturaldelta(self.auto_merge_after)
-                body += f"Enabled. rcmt automatically merges this in {after} and if all checks have passed.\n"
+                body += f"Enabled. rcmt automatically merges this in {after} and if all checks have passed.  \n"
         else:
-            body += "Disabled. Merge this manually.\n"
+            body += "Disabled. Merge this manually.  \n"
 
         if self.merge_once is True:
-            body += "**Ignore:** Close this PR and it will not be recreated again.\n"
+            body += "**Ignore:** Close this PR and it will not be recreated again.  \n"
         else:
-            body += "**Ignore:** This PR will be recreated if closed.\n"
+            body += "**Ignore:** This PR will be recreated if closed.  \n"
 
         body += """
 ---
@@ -319,14 +320,21 @@ class Base:
 
     """
 
-    def list_repositories(self) -> list[Repository]:
+    def list_repositories_with_open_pull_requests(
+        self,
+    ) -> Generator[Repository, None, None]:
+        raise NotImplementedError(
+            "class does not implement Base.list_open_pull_requests()"
+        )
+
+    def list_repositories(self, since: datetime.datetime) -> list[Repository]:
         """
+        :param since: Date and time of the last run of rcmt to find only those repositories that have received and update since.
+
         :return: List of all known repositories.
         :rtype: list[rcmt.source.Repository]
         """
-        raise NotImplementedError(
-            "class does not implement SourceLister.list_repositories()"
-        )
+        raise NotImplementedError("class does not implement Base.list_repositories()")
 
 
 def add_credentials_to_url(url: str, password: str, username: str = "") -> str:
